import IMServicePlugIn
from PyObjCTools.TestSupport import TestCase, expectedFailure


class TestIMServicePlugInChatRoomSupport(TestCase):
    @expectedFailure  # Definitions are likely part of the host application
    def testConstantsStr(self):
        self.assertIsInstance(IMServicePlugIn.IMAccountSettingServerHost, str)
        self.assertIsInstance(IMServicePlugIn.IMAccountSettingServerPort, str)
        self.assertIsInstance(IMServicePlugIn.IMAccountSettingLoginHandle, str)
        self.assertIsInstance(IMServicePlugIn.IMAccountSettingPassword, str)
        self.assertIsInstance(IMServicePlugIn.IMAccountSettingUsesSSL, str)

        self.assertIsInstance(IMServicePlugIn.IMSessionPropertyAvailability, str)
        self.assertIsInstance(IMServicePlugIn.IMSessionPropertyStatusMessage, str)
        self.assertIsInstance(IMServicePlugIn.IMSessionPropertyPictureData, str)
        self.assertIsInstance(IMServicePlugIn.IMSessionPropertyIdleDate, str)
        self.assertIsInstance(IMServicePlugIn.IMSessionPropertyIsInvisible, str)

        self.assertIsInstance(IMServicePlugIn.IMGroupListDefaultGroup, str)
        self.assertIsInstance(IMServicePlugIn.IMGroupListNameKey, str)
        self.assertIsInstance(IMServicePlugIn.IMGroupListPermissionsKey, str)
        self.assertIsInstance(IMServicePlugIn.IMGroupListHandlesKey, str)

        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyAvailability, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyStatusMessage, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyAuthorizationStatus, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyIdleDate, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyAlias, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyFirstName, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyLastName, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyEmailAddress, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyPictureIdentifier, str)
        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyPictureData, str)

        self.assertIsInstance(IMServicePlugIn.IMHandlePropertyCapabilities, str)
        self.assertIsInstance(IMServicePlugIn.IMHandleCapabilityMessaging, str)
        self.assertIsInstance(IMServicePlugIn.IMHandleCapabilityOfflineMessaging, str)
        self.assertIsInstance(IMServicePlugIn.IMHandleCapabilityChatRoom, str)
        self.assertIsInstance(IMServicePlugIn.IMHandleCapabilityHandlePicture, str)
        self.assertIsInstance(IMServicePlugIn.IMHandleCapabilityFileTransfer, str)

        self.assertIsInstance(IMServicePlugIn.IMAttributeFontFamily, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeFontSize, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeItalic, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeBold, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeUnderline, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeStrikethrough, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeLink, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributePreformatted, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeBaseWritingDirection, str)

        self.assertIsInstance(IMServicePlugIn.IMAttributeForegroundColor, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeBackgroundColor, str)
        self.assertIsInstance(IMServicePlugIn.IMAttributeMessageBackgroundColor, str)

    def testConstantsNum(self):
        self.assertEqual(IMServicePlugIn.IMSessionAvailabilityAway, 0)
        self.assertEqual(IMServicePlugIn.IMSessionAvailabilityAvailable, 1)

        self.assertEqual(IMServicePlugIn.IMGroupListCanReorderGroup, (1 << 0))
        self.assertEqual(IMServicePlugIn.IMGroupListCanRenameGroup, (1 << 1))
        self.assertEqual(IMServicePlugIn.IMGroupListCanAddNewMembers, (1 << 2))
        self.assertEqual(IMServicePlugIn.IMGroupListCanRemoveMembers, (1 << 3))
        self.assertEqual(IMServicePlugIn.IMGroupListCanReorderMembers, (1 << 4))

        self.assertEqual(IMServicePlugIn.IMHandleAvailabilityUnknown, -2)
        self.assertEqual(IMServicePlugIn.IMHandleAvailabilityOffline, -1)
        self.assertEqual(IMServicePlugIn.IMHandleAvailabilityAway, 0)
        self.assertEqual(IMServicePlugIn.IMHandleAvailabilityAvailable, 1)

        self.assertEqual(IMServicePlugIn.IMHandleAuthorizationStatusAccepted, 0)
        self.assertEqual(IMServicePlugIn.IMHandleAuthorizationStatusPending, 1)
        self.assertEqual(IMServicePlugIn.IMHandleAuthorizationStatusDeclined, 2)



import IMServicePlugIn
from PyObjCTools.TestSupport import TestCase, expectedFailure
import objc


class TestIMServicePlugInFileTransferSession(TestCase):
    @expectedFailure  # Class is probably part of the host application
    def testClasses(self):
        self.assertIsInstance(
            IMServicePlugIn.IMServicePlugInFileTransferSession, objc.objc_class
        )
        self.assertIsInstance(
            IMServicePlugIn.IMServicePlugInOutgoingFileTransferSession, objc.objc_class
        )
        self.assertIsInstance(
            IMServicePlugIn.IMServicePlugInIncomingFileTransferSession, objc.objc_class
        )



import IMServicePlugIn
from PyObjCTools.TestSupport import TestCase, expectedFailure
import objc


class TestIMServicePlugInFileTransfer(TestCase):
    @expectedFailure  # Class are likely part of the host application
    def testClasses(self):
        self.assertIsInstance(
            IMServicePlugIn.IMServicePlugInFileTransfer, objc.objc_class
        )
        self.assertIsInstance(
            IMServicePlugIn.IMServicePlugInOutgoingFileTransfer, objc.objc_class
        )
        self.assertIsInstance(
            IMServicePlugIn.IMServicePlugInIncomingFileTransfer, objc.objc_class
        )



# This file is generated by objective.metadata
#
# Last update: Sun Jul 11 21:38:50 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a


else:

    def selAorI(a, b):
        return b


misc = {}
misc.update(
    {
        "IMServicePlugInMessageInternal": objc.createStructType(
            "IMServicePlugInMessageInternal", b"{_IMServicePlugInMessageInternal=}", []
        )
    }
)
constants = """$IMAccountSettingLoginHandle$IMAccountSettingPassword$IMAccountSettingServerHost$IMAccountSettingServerPort$IMAccountSettingUsesSSL$IMAttributeBackgroundColor$IMAttributeBaseWritingDirection$IMAttributeBold$IMAttributeFontFamily$IMAttributeFontSize$IMAttributeForegroundColor$IMAttributeItalic$IMAttributeLink$IMAttributeMessageBackgroundColor$IMAttributePreformatted$IMAttributeStrikethrough$IMAttributeUnderline$IMGroupListDefaultGroup$IMGroupListHandlesKey$IMGroupListNameKey$IMGroupListPermissionsKey$IMHandleCapabilityChatRoom$IMHandleCapabilityFileTransfer$IMHandleCapabilityHandlePicture$IMHandleCapabilityMessaging$IMHandleCapabilityOfflineMessaging$IMHandlePropertyAlias$IMHandlePropertyAuthorizationStatus$IMHandlePropertyAvailability$IMHandlePropertyCapabilities$IMHandlePropertyEmailAddress$IMHandlePropertyFirstName$IMHandlePropertyIdleDate$IMHandlePropertyLastName$IMHandlePropertyPictureData$IMHandlePropertyPictureIdentifier$IMHandlePropertyStatusMessage$IMSessionPropertyAvailability$IMSessionPropertyIdleDate$IMSessionPropertyIsInvisible$IMSessionPropertyPictureData$IMSessionPropertyStatusMessage$"""
enums = """$IMGroupListCanAddNewMembers@4$IMGroupListCanRemoveMembers@8$IMGroupListCanRenameGroup@2$IMGroupListCanReorderGroup@1$IMGroupListCanReorderMembers@16$IMHandleAuthorizationStatusAccepted@0$IMHandleAuthorizationStatusDeclined@2$IMHandleAuthorizationStatusPending@1$IMHandleAvailabilityAvailable@1$IMHandleAvailabilityAway@0$IMHandleAvailabilityOffline@-1$IMHandleAvailabilityUnknown@-2$IMSessionAvailabilityAvailable@1$IMSessionAvailabilityAway@0$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"acceptAuthorizationRequestFromHandle:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"addGroups:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"addHandles:toGroup:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"declineAuthorizationRequestFromHandle:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"declineChatRoomInvitation:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handleDidStartTyping:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handleDidStopTyping:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"handles:didJoinChatRoom:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"handles:didLeaveChatRoom:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"initWithServiceApplication:",
        {"required": True, "retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"inviteHandles:toChatRoom:withMessage:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"joinChatRoom:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"leaveChatRoom:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"login", {"required": True, "retval": {"type": b"v"}})
    r(b"NSObject", b"logout", {"required": True, "retval": {"type": b"v"}})
    r(
        b"NSObject",
        b"plugInDidFailToAuthenticate",
        {"required": True, "retval": {"type": b"v"}},
    )
    r(
        b"NSObject",
        b"plugInDidJoinChatRoom:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"plugInDidLeaveChatRoom:error:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(b"NSObject", b"plugInDidLogIn", {"required": True, "retval": {"type": b"v"}})
    r(
        b"NSObject",
        b"plugInDidLogOutWithError:reconnect:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "Z"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidReceiveAuthorizationRequestFromHandle:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"plugInDidReceiveInvitation:forChatRoom:fromHandle:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidReceiveMessage:forChatRoom:fromHandle:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidReceiveMessage:fromHandle:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidReceiveNotice:forChatRoom:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidSendMessage:toChatRoom:error:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidSendMessage:toHandle:error:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidUpdateGroupList:error:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"plugInDidUpdateProperties:ofHandle:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"removeGroups:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"removeHandles:fromGroup:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"renameGroup:toGroup:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"reorderGroups:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"reorderHandles:inGroup:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(b"NSObject", b"requestGroupList", {"required": True, "retval": {"type": b"v"}})
    r(
        b"NSObject",
        b"requestPictureForHandle:withIdentifier:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"sendAuthorizationRequestToHandle:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"sendMessage:toChatRoom:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"sendMessage:toHandle:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"updateAccountSettings:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"updateSessionProperties:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"userDidStartTypingToHandle:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"userDidStopTypingToHandle:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import IMServicePlugIn
from PyObjCTools.TestSupport import TestCase
import objc


class TestIMServicePlugInProtocolsHelper(IMServicePlugIn.NSObject):
    def plugInDidLogOutWithError_reconnect_(self, p, r):
        pass


class TestIMServicePlugInProtocols(TestCase):
    def testProtocols(self):
        objc.protocolNamed("IMServicePlugIn")
        objc.protocolNamed("IMServiceApplication")

        self.assertArgIsBOOL(
            TestIMServicePlugInProtocolsHelper.plugInDidLogOutWithError_reconnect_, 1
        )
